==> eam-wshub-proxyclient-11.4-6-sources.jar: net/datastream/schemas/mp_entities/casemanagement_001/FollowupWODetails.java <==

package net.datastream.schemas.mp_entities.casemanagement_001;

import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlRootElement;
import javax.xml.bind.annotation.XmlType;
import net.datastream.schemas.mp_fields.CLASSID_Type;
import net.datastream.schemas.mp_fields.STATUS_Type;
import net.datastream.schemas.mp_fields.STDWOID_Type;
import net.datastream.schemas.mp_fields.TASKS_Type;
import net.datastream.schemas.mp_fields.TRADEID_Type;
import net.datastream.schemas.mp_fields.TYPE_Type;
import net.datastream.schemas.mp_fields.WOID_Type;
import net.datastream.schemas.mp_fields.WOPRIORITY_Type;


/**
 * <p>Classe Java pour anonymous complex type.
 * 
 * <p>Le fragment de schéma suivant indique le contenu attendu figurant dans cette classe.
 * 
 * <pre>
 * &lt;complexType>
 *   &lt;complexContent>
 *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *       &lt;sequence>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}WODESCRIPTION" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}STANDARDWO" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}WORKORDERTYPE" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}WORKORDERCLASSID" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}WORKORDERSTATUS" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}WOPRIORITY" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}TASKSID" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}CASETASKJOBPLANID" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}TRADEID" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}ESTIMATEDHOURS" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}PERSONS" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}FOLLOWUPWORKORDER" minOccurs="0"/>
 *       &lt;/sequence>
 *     &lt;/restriction>
 *   &lt;/complexContent>
 * &lt;/complexType>
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "", propOrder = {
    "wodescription",
    "standardwo",
    "workordertype",
    "workorderclassid",
    "workorderstatus",
    "wopriority",
    "tasksid",
    "casetaskjobplanid",
    "tradeid",
    "estimatedhours",
    "persons",
    "followupworkorder"
})
@XmlRootElement(name = "FollowupWODetails")
public class FollowupWODetails {

    @XmlElement(name = "WODESCRIPTION", namespace = "http://schemas.datastream.net/MP_fields")
    protected String wodescription;
    @XmlElement(name = "STANDARDWO", namespace = "http://schemas.datastream.net/MP_fields")
    protected STDWOID_Type standardwo;
    @XmlElement(name = "WORKORDERTYPE", namespace = "http://schemas.datastream.net/MP_fields")
    protected TYPE_Type workordertype;
    @XmlElement(name = "WORKORDERCLASSID", namespace = "http://schemas.datastream.net/MP_fields")
    protected CLASSID_Type workorderclassid;
    @XmlElement(name = "WORKORDERSTATUS", namespace = "http://schemas.datastream.net/MP_fields")
    protected STATUS_Type workorderstatus;
    @XmlElement(name = "WOPRIORITY", namespace = "http://schemas.datastream.net/MP_fields")
    protected WOPRIORITY_Type wopriority;
    @XmlElement(name = "TASKSID", namespace = "http://schemas.datastream.net/MP_fields")
    protected TASKS_Type tasksid;
    @XmlElement(name = "CASETASKJOBPLANID", namespace = "http://schemas.datastream.net/MP_fields")
    protected TASKS_Type casetaskjobplanid;
    @XmlElement(name = "TRADEID", namespace = "http://schemas.datastream.net/MP_fields")
    protected TRADEID_Type tradeid;
    @XmlElement(name = "ESTIMATEDHOURS", namespace = "http://schemas.datastream.net/MP_fields")
    protected Double estimatedhours;
    @XmlElement(name = "PERSONS", namespace = "http://schemas.datastream.net/MP_fields")
    protected Long persons;
    @XmlElement(name = "FOLLOWUPWORKORDER", namespace = "http://schemas.datastream.net/MP_fields")
    protected WOID_Type followupworkorder;

    /**
     * Obtient la valeur de la propriété wodescription.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getWODESCRIPTION() {
        return wodescription;
    }

    /**
     * Définit la valeur de la propriété wodescription.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setWODESCRIPTION(String value) {
        this.wodescription = value;
    }

    /**
     * Obtient la valeur de la propriété standardwo.
     * 
     * @return
     *     possible object is
     *     {@link STDWOID_Type }
     *     
     */
    public STDWOID_Type getSTANDARDWO() {
        return standardwo;
    }

    /**
     * Définit la valeur de la propriété standardwo.
     * 
     * @param value
     *     allowed object is
     *     {@link STDWOID_Type }
     *     
     */
    public void setSTANDARDWO(STDWOID_Type value) {
        this.standardwo = value;
    }

    /**
     * Obtient la valeur de la propriété workordertype.
     * 
     * @return
     *     possible object is
     *     {@link TYPE_Type }
     *     
     */
    public TYPE_Type getWORKORDERTYPE() {
        return workordertype;
    }

    /**
     * Définit la valeur de la propriété workordertype.
     * 
     * @param value
     *     allowed object is
     *     {@link TYPE_Type }
     *     
     */
    public void setWORKORDERTYPE(TYPE_Type value) {
        this.workordertype = value;
    }

    /**
     * Obtient la valeur de la propriété workorderclassid.
     * 
     * @return
     *     possible object is
     *     {@link CLASSID_Type }
     *     
     */
    public CLASSID_Type getWORKORDERCLASSID() {
        return workorderclassid;
    }

    /**
     * Définit la valeur de la propriété workorderclassid.
     * 
     * @param value
     *     allowed object is
     *     {@link CLASSID_Type }
     *     
     */
    public void setWORKORDERCLASSID(CLASSID_Type value) {
        this.workorderclassid = value;
    }

    /**
     * Obtient la valeur de la propriété workorderstatus.
     * 
     * @return
     *     possible object is
     *     {@link STATUS_Type }
     *     
     */
    public STATUS_Type getWORKORDERSTATUS() {
        return workorderstatus;
    }

    /**
     * Définit la valeur de la propriété workorderstatus.
     * 
     * @param value
     *     allowed object is
     *     {@link STATUS_Type }
     *     
     */
    public void setWORKORDERSTATUS(STATUS_Type value) {
        this.workorderstatus = value;
    }

    /**
     * Obtient la valeur de la propriété wopriority.
     * 
     * @return
     *     possible object is
     *     {@link WOPRIORITY_Type }
     *     
     */
    public WOPRIORITY_Type getWOPRIORITY() {
        return wopriority;
    }

    /**
     * Définit la valeur de la propriété wopriority.
     * 
     * @param value
     *     allowed object is
     *     {@link WOPRIORITY_Type }
     *     
     */
    public void setWOPRIORITY(WOPRIORITY_Type value) {
        this.wopriority = value;
    }

    /**
     * Obtient la valeur de la propriété tasksid.
     * 
     * @return
     *     possible object is
     *     {@link TASKS_Type }
     *     
     */
    public TASKS_Type getTASKSID() {
        return tasksid;
    }

    /**
     * Définit la valeur de la propriété tasksid.
     * 
     * @param value
     *     allowed object is
     *     {@link TASKS_Type }
     *     
     */
    public void setTASKSID(TASKS_Type value) {
        this.tasksid = value;
    }

    /**
     * Obtient la valeur de la propriété casetaskjobplanid.
     * 
     * @return
     *     possible object is
     *     {@link TASKS_Type }
     *     
     */
    public TASKS_Type getCASETASKJOBPLANID() {
        return casetaskjobplanid;
    }

    /**
     * Définit la valeur de la propriété casetaskjobplanid.
     * 
     * @param value
     *     allowed object is
     *     {@link TASKS_Type }
     *     
     */
    public void setCASETASKJOBPLANID(TASKS_Type value) {
        this.casetaskjobplanid = value;
    }

    /**
     * Obtient la valeur de la propriété tradeid.
     * 
     * @return
     *     possible object is
     *     {@link TRADEID_Type }
     *     
     */
    public TRADEID_Type getTRADEID() {
        return tradeid;
    }

    /**
     * Définit la valeur de la propriété tradeid.
     * 
     * @param value
     *     allowed object is
     *     {@link TRADEID_Type }
     *     
     */
    public void setTRADEID(TRADEID_Type value) {
        this.tradeid = value;
    }

    /**
     * Obtient la valeur de la propriété estimatedhours.
     * 
     * @return
     *     possible object is
     *     {@link Double }
     *     
     */
    public Double getESTIMATEDHOURS() {
        return estimatedhours;
    }

    /**
     * Définit la valeur de la propriété estimatedhours.
     * 
     * @param value
     *     allowed object is
     *     {@link Double }
     *     
     */
    public void setESTIMATEDHOURS(Double value) {
        this.estimatedhours = value;
    }

    /**
     * Obtient la valeur de la propriété persons.
     * 
     * @return
     *     possible object is
     *     {@link Long }
     *     
     */
    public Long getPERSONS() {
        return persons;
    }

    /**
     * Définit la valeur de la propriété persons.
     * 
     * @param value
     *     allowed object is
     *     {@link Long }
     *     
     */
    public void setPERSONS(Long value) {
        this.persons = value;
    }

    /**
     * Obtient la valeur de la propriété followupworkorder.
     * 
     * @return
     *     possible object is
     *     {@link WOID_Type }
     *     
     */
    public WOID_Type getFOLLOWUPWORKORDER() {
        return followupworkorder;
    }

    /**
     * Définit la valeur de la propriété followupworkorder.
     * 
     * @param value
     *     allowed object is
     *     {@link WOID_Type }
     *     
     */
    public void setFOLLOWUPWORKORDER(WOID_Type value) {
        this.followupworkorder = value;
    }

}

==> eam-wshub-proxyclient-12.0-sources.jar: net/datastream/schemas/mp_entities/casemanagement_001/FollowupWODetails.java <==

package net.datastream.schemas.mp_entities.casemanagement_001;

import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlRootElement;
import javax.xml.bind.annotation.XmlType;
import net.datastream.schemas.mp_fields.CLASSID_Type;
import net.datastream.schemas.mp_fields.STATUS_Type;
import net.datastream.schemas.mp_fields.STDWOID_Type;
import net.datastream.schemas.mp_fields.TASKS_Type;
import net.datastream.schemas.mp_fields.TRADEID_Type;
import net.datastream.schemas.mp_fields.TYPE_Type;
import net.datastream.schemas.mp_fields.WOID_Type;
import net.datastream.schemas.mp_fields.WOPRIORITY_Type;


/**
 * <p>Java class for anonymous complex type.
 * 
 * <p>The following schema fragment specifies the expected content contained within this class.
 * 
 * <pre>
 * &lt;complexType>
 *   &lt;complexContent>
 *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *       &lt;sequence>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}WODESCRIPTION" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}STANDARDWO" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}WORKORDERTYPE" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}WORKORDERCLASSID" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}WORKORDERSTATUS" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}WOPRIORITY" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}TASKSID" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}CASETASKJOBPLANID" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}TRADEID" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}ESTIMATEDHOURS" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}PERSONS" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}FOLLOWUPWORKORDER" minOccurs="0"/>
 *       &lt;/sequence>
 *     &lt;/restriction>
 *   &lt;/complexContent>
 * &lt;/complexType>
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "", propOrder = {
    "wodescription",
    "standardwo",
    "workordertype",
    "workorderclassid",
    "workorderstatus",
    "wopriority",
    "tasksid",
    "casetaskjobplanid",
    "tradeid",
    "estimatedhours",
    "persons",
    "followupworkorder"
})
@XmlRootElement(name = "FollowupWODetails")
public class FollowupWODetails {

    @XmlElement(name = "WODESCRIPTION", namespace = "http://schemas.datastream.net/MP_fields")
    protected String wodescription;
    @XmlElement(name = "STANDARDWO", namespace = "http://schemas.datastream.net/MP_fields")
    protected STDWOID_Type standardwo;
    @XmlElement(name = "WORKORDERTYPE", namespace = "http://schemas.datastream.net/MP_fields")
    protected TYPE_Type workordertype;
    @XmlElement(name = "WORKORDERCLASSID", namespace = "http://schemas.datastream.net/MP_fields")
    protected CLASSID_Type workorderclassid;
    @XmlElement(name = "WORKORDERSTATUS", namespace = "http://schemas.datastream.net/MP_fields")
    protected STATUS_Type workorderstatus;
    @XmlElement(name = "WOPRIORITY", namespace = "http://schemas.datastream.net/MP_fields")
    protected WOPRIORITY_Type wopriority;
    @XmlElement(name = "TASKSID", namespace = "http://schemas.datastream.net/MP_fields")
    protected TASKS_Type tasksid;
    @XmlElement(name = "CASETASKJOBPLANID", namespace = "http://schemas.datastream.net/MP_fields")
    protected TASKS_Type casetaskjobplanid;
    @XmlElement(name = "TRADEID", namespace = "http://schemas.datastream.net/MP_fields")
    protected TRADEID_Type tradeid;
    @XmlElement(name = "ESTIMATEDHOURS", namespace = "http://schemas.datastream.net/MP_fields")
    protected Double estimatedhours;
    @XmlElement(name = "PERSONS", namespace = "http://schemas.datastream.net/MP_fields")
    protected Long persons;
    @XmlElement(name = "FOLLOWUPWORKORDER", namespace = "http://schemas.datastream.net/MP_fields")
    protected WOID_Type followupworkorder;

    /**
     * Gets the value of the wodescription property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getWODESCRIPTION() {
        return wodescription;
    }

    /**
     * Sets the value of the wodescription property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setWODESCRIPTION(String value) {
        this.wodescription = value;
    }

    /**
     * Gets the value of the standardwo property.
     * 
     * @return
     *     possible object is
     *     {@link STDWOID_Type }
     *     
     */
    public STDWOID_Type getSTANDARDWO() {
        return standardwo;
    }

    /**
     * Sets the value of the standardwo property.
     * 
     * @param value
     *     allowed object is
     *     {@link STDWOID_Type }
     *     
     */
    public void setSTANDARDWO(STDWOID_Type value) {
        this.standardwo = value;
    }

    /**
     * Gets the value of the workordertype property.
     * 
     * @return
     *     possible object is
     *     {@link TYPE_Type }
     *     
     */
    public TYPE_Type getWORKORDERTYPE() {
        return workordertype;
    }

    /**
     * Sets the value of the workordertype property.
     * 
     * @param value
     *     allowed object is
     *     {@link TYPE_Type }
     *     
     */
    public void setWORKORDERTYPE(TYPE_Type value) {
        this.workordertype = value;
    }

    /**
     * Gets the value of the workorderclassid property.
     * 
     * @return
     *     possible object is
     *     {@link CLASSID_Type }
     *     
     */
    public CLASSID_Type getWORKORDERCLASSID() {
        return workorderclassid;
    }

    /**
     * Sets the value of the workorderclassid property.
     * 
     * @param value
     *     allowed object is
     *     {@link CLASSID_Type }
     *     
     */
    public void setWORKORDERCLASSID(CLASSID_Type value) {
        this.workorderclassid = value;
    }

    /**
     * Gets the value of the workorderstatus property.
     * 
     * @return
     *     possible object is
     *     {@link STATUS_Type }
     *     
     */
    public STATUS_Type getWORKORDERSTATUS() {
        return workorderstatus;
    }

    /**
     * Sets the value of the workorderstatus property.
     * 
     * @param value
     *     allowed object is
     *     {@link STATUS_Type }
     *     
     */
    public void setWORKORDERSTATUS(STATUS_Type value) {
        this.workorderstatus = value;
    }

    /**
     * Gets the value of the wopriority property.
     * 
     * @return
     *     possible object is
     *     {@link WOPRIORITY_Type }
     *     
     */
    public WOPRIORITY_Type getWOPRIORITY() {
        return wopriority;
    }

    /**
     * Sets the value of the wopriority property.
     * 
     * @param value
     *     allowed object is
     *     {@link WOPRIORITY_Type }
     *     
     */
    public void setWOPRIORITY(WOPRIORITY_Type value) {
        this.wopriority = value;
    }

    /**
     * Gets the value of the tasksid property.
     * 
     * @return
     *     possible object is
     *     {@link TASKS_Type }
     *     
     */
    public TASKS_Type getTASKSID() {
        return tasksid;
    }

    /**
     * Sets the value of the tasksid property.
     * 
     * @param value
     *     allowed object is
     *     {@link TASKS_Type }
     *     
     */
    public void setTASKSID(TASKS_Type value) {
        this.tasksid = value;
    }

    /**
     * Gets the value of the casetaskjobplanid property.
     * 
     * @return
     *     possible object is
     *     {@link TASKS_Type }
     *     
     */
    public TASKS_Type getCASETASKJOBPLANID() {
        return casetaskjobplanid;
    }

    /**
     * Sets the value of the casetaskjobplanid property.
     * 
     * @param value
     *     allowed object is
     *     {@link TASKS_Type }
     *     
     */
    public void setCASETASKJOBPLANID(TASKS_Type value) {
        this.casetaskjobplanid = value;
    }

    /**
     * Gets the value of the tradeid property.
     * 
     * @return
     *     possible object is
     *     {@link TRADEID_Type }
     *     
     */
    public TRADEID_Type getTRADEID() {
        return tradeid;
    }

    /**
     * Sets the value of the tradeid property.
     * 
     * @param value
     *     allowed object is
     *     {@link TRADEID_Type }
     *     
     */
    public void setTRADEID(TRADEID_Type value) {
        this.tradeid = value;
    }

    /**
     * Gets the value of the estimatedhours property.
     * 
     * @return
     *     possible object is
     *     {@link Double }
     *     
     */
    public Double getESTIMATEDHOURS() {
        return estimatedhours;
    }

    /**
     * Sets the value of the estimatedhours property.
     * 
     * @param value
     *     allowed object is
     *     {@link Double }
     *     
     */
    public void setESTIMATEDHOURS(Double value) {
        this.estimatedhours = value;
    }

    /**
     * Gets the value of the persons property.
     * 
     * @return
     *     possible object is
     *     {@link Long }
     *     
     */
    public Long getPERSONS() {
        return persons;
    }

    /**
     * Sets the value of the persons property.
     * 
     * @param value
     *     allowed object is
     *     {@link Long }
     *     
     */
    public void setPERSONS(Long value) {
        this.persons = value;
    }

    /**
     * Gets the value of the followupworkorder property.
     * 
     * @return
     *     possible object is
     *     {@link WOID_Type }
     *     
     */
    public WOID_Type getFOLLOWUPWORKORDER() {
        return followupworkorder;
    }

    /**
     * Sets the value of the followupworkorder property.
     * 
     * @param value
     *     allowed object is
     *     {@link WOID_Type }
     *     
     */
    public void setFOLLOWUPWORKORDER(WOID_Type value) {
        this.followupworkorder = value;
    }

}
